==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/workorderadditionalcosts_001/WorkOrderAdditionalCosts.java <==

package net.datastream.schemas.mp_entities.workorderadditionalcosts_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.COSTTYPEID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFO;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOADDITIONALCOSTQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UNITPRICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activityid",
    "description",
    "costtypeid",
    "createddate",
    "woadditionalcostqty",
    "unitprice",
    "multiequipsplitinfo",
    "jobsequence"
})
@XmlRootElement(name = "WorkOrderAdditionalCosts")
public class WorkOrderAdditionalCosts {

    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String description;
    @XmlElement(name = "COSTTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected COSTTYPEID_Type costtypeid;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME createddate;
    @XmlElement(name = "WOADDITIONALCOSTQTY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY woadditionalcostqty;
    @XmlElement(name = "UNITPRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT unitprice;
    @XmlElement(name = "MULTIEQUIPSPLITINFO", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFO multiequipsplitinfo;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété costtypeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTTYPEID_Type }
     *     
     */
    public COSTTYPEID_Type getCOSTTYPEID() {
        return costtypeid;
    }

    /**
     * Définit la valeur de la propriété costtypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTTYPEID_Type }
     *     
     */
    public void setCOSTTYPEID(COSTTYPEID_Type value) {
        this.costtypeid = value;
    }

    /**
     * Obtient la valeur de la propriété createddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Définit la valeur de la propriété createddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Obtient la valeur de la propriété woadditionalcostqty.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWOADDITIONALCOSTQTY() {
        return woadditionalcostqty;
    }

    /**
     * Définit la valeur de la propriété woadditionalcostqty.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWOADDITIONALCOSTQTY(QUANTITY value) {
        this.woadditionalcostqty = value;
    }

    /**
     * Obtient la valeur de la propriété unitprice.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getUNITPRICE() {
        return unitprice;
    }

    /**
     * Définit la valeur de la propriété unitprice.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setUNITPRICE(AMOUNT value) {
        this.unitprice = value;
    }

    /**
     * Obtient la valeur de la propriété multiequipsplitinfo.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFO }
     *     
     */
    public MULTIEQUIPSPLITINFO getMULTIEQUIPSPLITINFO() {
        return multiequipsplitinfo;
    }

    /**
     * Définit la valeur de la propriété multiequipsplitinfo.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFO }
     *     
     */
    public void setMULTIEQUIPSPLITINFO(MULTIEQUIPSPLITINFO value) {
        this.multiequipsplitinfo = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/workorderadditionalcosts_001/WorkOrderAdditionalCosts.java <==

package net.datastream.schemas.mp_entities.workorderadditionalcosts_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.COSTTYPEID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFO;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOADDITIONALCOSTQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UNITPRICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activityid",
    "description",
    "costtypeid",
    "createddate",
    "woadditionalcostqty",
    "unitprice",
    "multiequipsplitinfo",
    "jobsequence"
})
@XmlRootElement(name = "WorkOrderAdditionalCosts")
public class WorkOrderAdditionalCosts {

    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String description;
    @XmlElement(name = "COSTTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected COSTTYPEID_Type costtypeid;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME createddate;
    @XmlElement(name = "WOADDITIONALCOSTQTY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY woadditionalcostqty;
    @XmlElement(name = "UNITPRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT unitprice;
    @XmlElement(name = "MULTIEQUIPSPLITINFO", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFO multiequipsplitinfo;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the costtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTTYPEID_Type }
     *     
     */
    public COSTTYPEID_Type getCOSTTYPEID() {
        return costtypeid;
    }

    /**
     * Sets the value of the costtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTTYPEID_Type }
     *     
     */
    public void setCOSTTYPEID(COSTTYPEID_Type value) {
        this.costtypeid = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the woadditionalcostqty property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWOADDITIONALCOSTQTY() {
        return woadditionalcostqty;
    }

    /**
     * Sets the value of the woadditionalcostqty property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWOADDITIONALCOSTQTY(QUANTITY value) {
        this.woadditionalcostqty = value;
    }

    /**
     * Gets the value of the unitprice property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getUNITPRICE() {
        return unitprice;
    }

    /**
     * Sets the value of the unitprice property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setUNITPRICE(AMOUNT value) {
        this.unitprice = value;
    }

    /**
     * Gets the value of the multiequipsplitinfo property.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFO }
     *     
     */
    public MULTIEQUIPSPLITINFO getMULTIEQUIPSPLITINFO() {
        return multiequipsplitinfo;
    }

    /**
     * Sets the value of the multiequipsplitinfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFO }
     *     
     */
    public void setMULTIEQUIPSPLITINFO(MULTIEQUIPSPLITINFO value) {
        this.multiequipsplitinfo = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}
